@@ -1,8 +1,9 @@
 # mypy: allow-untyped-defs
 import operator
+from collections.abc import Sequence
 from enum import Enum
 from functools import partial, reduce
-from typing import Callable, List, Optional, Sequence, Tuple, Type, Union
+from typing import Callable, Optional, Union
 
 import torch
 import torch._prims_common as utils
@@ -231,8 +232,8 @@ def TensorMeta(
     if isinstance(tensorlike, Number):
         assert not shape and (shape is None or isinstance(shape, Sequence))
         assert not strides and (strides is None or isinstance(strides, Sequence))
-        inferred_shape: Tuple[int, ...] = ()
-        inferred_strides: Tuple[int, ...] = ()
+        inferred_shape: tuple[int, ...] = ()
+        inferred_strides: tuple[int, ...] = ()
         inferred_dtype = type_to_dtype(type(tensorlike))
         inferred_device = torch.device("cpu")
         # TODO: This looks wrong, a number that is wrapped into a tensor
@@ -266,7 +267,7 @@ def TensorMeta(
 def _make_prim(
     *,
     schema: str,
-    return_type: Union[RETURN_TYPE, Tuple[RETURN_TYPE, ...]],
+    return_type: Union[RETURN_TYPE, tuple[RETURN_TYPE, ...]],
     meta: Callable,
     impl_aten: Callable,
     doc: str,
@@ -301,7 +302,7 @@ def _make_prim(
         else:
             return _prim_impl(*args, **kwargs)
 
-    name = schema.split("(")[0]
+    name = schema.split("(", maxsplit=1)[0]
     schema = schema[len(name) :]
 
     # register non-functional ops with old custom ops API
@@ -312,10 +313,11 @@ def _make_prim(
         prim_autograd_impl.impl(name, _autograd_impl)
         prim_meta_impl.impl(name, meta)
     else:
-        mutates_args = []
-        for arg in cpp_schema.arguments:
-            if arg.alias_info is not None and arg.alias_info.is_write:
-                mutates_args.append(arg.name)
+        mutates_args = [
+            arg.name
+            for arg in cpp_schema.arguments
+            if arg.alias_info is not None and arg.alias_info.is_write
+        ]
         prim_def = torch.library.custom_op(
             "prims::" + name,
             _prim_impl,
@@ -382,7 +384,7 @@ class ELEMENTWISE_PRIM_TYPE_PROMOTION_KIND(Enum):
 def _prim_elementwise_meta(
     *args,
     type_promotion: ELEMENTWISE_PRIM_TYPE_PROMOTION_KIND,
-    args_with_fixed_dtypes: Optional[Tuple[TensorLikeType, ...]] = None,
+    args_with_fixed_dtypes: Optional[tuple[TensorLikeType, ...]] = None,
 ) -> FakeTensor:
     """
     Meta function for elementwise operations that produce outputs in the same dtype
@@ -1255,7 +1257,11 @@ as_strided = _make_prim(
 def _broadcast_in_dim_meta(
     a: TensorLikeType, shape: ShapeType, broadcast_dimensions: Sequence[int]
 ):
-    from torch.fx.experimental.symbolic_shapes import guard_size_oblivious
+    from torch.fx.experimental.symbolic_shapes import (
+        guard_or_false,
+        guard_or_true,
+        sym_or,
+    )
 
     # Type checks
     assert isinstance(a, TensorLike)
@@ -1282,11 +1288,10 @@ def _broadcast_in_dim_meta(
 
     # shape must be broadcastable to
     for idx, new_idx in enumerate(broadcast_dimensions):
-        if not guard_size_oblivious(a.shape[idx] == 1):
-            torch._check(
-                a.shape[idx] == shape[new_idx],
-                lambda: f"{a.shape[idx]} must be broadcastable to {shape[new_idx]}",
-            )
+        torch._check(
+            sym_or(a.shape[idx] == 1, shape[new_idx] == a.shape[idx]),
+            lambda: f"{a.shape[idx]} must be broadcastable to {shape[new_idx]}",
+        )
 
     new_strides = []
     original_idx = 0
@@ -1294,13 +1299,21 @@ def _broadcast_in_dim_meta(
         if idx in broadcast_dimensions:
             # Assigns a stride of zero to dimensions
             # which were actually broadcast
-            if guard_size_oblivious(a.shape[original_idx] != shape[idx]):
-                new_strides.append(0)
+            if guard_or_false(a.shape[original_idx] == 1):
+                if guard_or_false(a.shape[original_idx] == shape[idx]):
+                    new_strides.append(a.stride()[original_idx])
+                else:
+                    new_strides.append(0)
             else:
+                torch._check(
+                    a.shape[original_idx] == shape[idx],
+                    lambda: f"non-broadcasting semantics require {a.shape[original_idx]} == {shape[idx]}",
+                )
                 new_strides.append(a.stride()[original_idx])
             original_idx = original_idx + 1
         else:
-            if guard_size_oblivious(shape[idx] != 1):
+            if guard_or_true(shape[idx] != 1):
+                # consistent with previous use of guard_size_oblivious
                 new_strides.append(0)
             elif original_idx == a.ndim:
                 new_strides.append(1)
@@ -1357,7 +1370,7 @@ def _validate_collapse_args(a: Tensor, start: int, end: int) -> None:
     )
 
 
-def _collapsed_shape(shape: ShapeType, start: int, end: int) -> Tuple[int, ...]:
+def _collapsed_shape(shape: ShapeType, start: int, end: int) -> tuple[int, ...]:
     """
     Returns the shape of a with dims in [start, end) merged into a single dimension.
     """
@@ -1373,7 +1386,7 @@ def _collapsed_shape(shape: ShapeType, start: int, end: int) -> Tuple[int, ...]:
 
 def _collapse_view_helper(
     a: TensorLikeType, start: int, end: int
-) -> Tuple[Optional[ShapeType], Optional[StrideType]]:
+) -> tuple[Optional[ShapeType], Optional[StrideType]]:
     assert isinstance(a, TensorLike)
 
     from torch.fx.experimental.symbolic_shapes import guard_size_oblivious
@@ -1518,186 +1531,6 @@ def expand_dims(
     return broadcast_in_dim(a, new_shape, broadcast_dimensions)
 
 
-# Note: saves the Python slice object because we're about to clobber its name with the slice prim
-pyslice: Type[slice] = slice  # type: ignore[has-type]
-
-
-def _slice_meta(
-    a: TensorLikeType,
-    start_indices: DimsSequenceType,
-    limit_indices: DimsSequenceType,
-    strides: Optional[StrideType] = None,
-) -> TensorLikeType:
-    _strides = strides if strides is not None else [1] * len(start_indices)
-
-    if a.ndim != len(start_indices):
-        msg = f"Attempting to slice tensor of rank {a.ndim} with start_indices of length {len(start_indices)}!"
-        raise ValueError(msg)
-
-    if a.ndim != len(limit_indices):
-        msg = f"Attempting to slice tensor of rank {a.ndim} with limit_indices of length {len(limit_indices)}!"
-        raise ValueError(msg)
-
-    if a.ndim != len(_strides):
-        msg = f"Attempting to slice tensor of rank {a.ndim} with strides of length {len(limit_indices)}!"
-        raise ValueError(msg)
-
-    for x, y in zip(start_indices, a.shape):
-        if x < 0:
-            msg = f"Attempting to slice a tensor with a negative start index of {x}!"
-            raise ValueError(msg)
-        if x > y:
-            msg = (
-                f"Attempting to slice a tensor but a start index in {start_indices} is greater than"
-                f" the length of its corresponding dimension in shape {a.shape}"
-            )
-            raise ValueError(msg)
-
-    for x, y, z in zip(limit_indices, a.shape, start_indices):
-        if x < 0:
-            msg = f"Attempting to slice a tensor with a negative stop index of {x}!"
-            raise ValueError(msg)
-        if x > y:
-            msg = (
-                f"Attempting to slice a tensor but a stop index in {limit_indices} is greater than the length of "
-                f" its corresponding dimension in shape {a.shape}"
-            )
-            raise ValueError(msg)
-        if x < z:
-            msg = (
-                f"Attempting to slice a tensor but a start index in {x} is greater than "
-                f" its corresponding stop index {z}"
-            )
-
-    for x in _strides:
-        if x <= 0:
-            msg = f"Attempting to slice a tensor with a non-positive step of {x}!"
-            raise ValueError(msg)
-
-    new_shape = []
-    for x, y, z in zip(start_indices, limit_indices, _strides):
-        new_shape.append(1 + (y - x - 1) // z)
-
-    new_strides = []
-    for x, y in zip(a.stride(), _strides):
-        new_strides.append(x * y)
-
-    return a.as_strided(new_shape, new_strides, a.storage_offset())
-
-
-def _slice_aten(
-    a: Tensor,
-    start_indices: DimsSequenceType,
-    limit_indices: DimsSequenceType,
-    strides: Optional[StrideType] = None,
-) -> Tensor:
-    _strides = strides if strides is not None else [1] * len(start_indices)
-
-    slices = []
-    for start, stop, step in zip(start_indices, limit_indices, _strides):
-        slices.append(pyslice(start, stop, step))
-
-    return operator.getitem(a, slices)  # type: ignore[call-overload]
-
-
-_slice_doc = """
-    Creates a view of a "bounding box" within the tensor.
-
-    The bounding box is specified independently in each of the tensor's dimensions.
-    start_indices and limit_indices describe the box's boundaries for their corresponding
-    dimensions. If strides is specified then they specify the step size between elements
-    in their corresponding dimension.
-
-    This operation is analogous to slicing in NumPy, but does not permit slices where
-    the stop indices are less than the start indices.
-    """
-
-slice = _make_prim(
-    schema="slice(Tensor(a) a, SymInt[] start_indices, SymInt[] limit_indices, SymInt[]? strides=None) -> Tensor(a)",
-    meta=_slice_meta,
-    impl_aten=_slice_aten,
-    return_type=RETURN_TYPE.VIEW,
-    doc=_slice_doc,
-)
-
-
-def _slice_in_dim_meta(
-    a: TensorLikeType,
-    start_index: int,
-    limit_index: int,
-    stride: int = 1,
-    axis: int = 0,
-) -> TensorLikeType:
-    if axis < 0:
-        msg = f"slice_in_dim: received a negative axis {axis}"
-        raise ValueError(msg)
-    if axis >= a.ndim:
-        msg = f"slice_in_dim: axis {axis} is greater or equal to the rank {a.ndim} of the tensor"
-        raise ValueError(msg)
-
-    if start_index < 0:
-        msg = f"slice_in_dim: received a negative start_index {start_index}"
-        raise ValueError(msg)
-
-    if start_index > a.shape[axis]:
-        msg = f"slice_in_dim: start_index is greater than the length {start_index} of dimension {axis}"
-        raise ValueError(msg)
-
-    if limit_index > a.shape[axis]:
-        msg = f"slice_in_dim: limit_index is greater than the length {limit_index} of dimension {axis}"
-        raise ValueError(msg)
-
-    if limit_index < start_index:
-        msg = f"slice_in_dim: received a limit_index {limit_index} less than the start_index {start_index}"
-        raise ValueError(msg)
-
-    if stride < 0:
-        msg = f"slice_in_dim: received a non-positive stride of {stride}!"
-        raise ValueError(msg)
-
-    start_indices = [0] * a.ndim
-    limit_indices = list(a.shape)
-    strides = [1] * a.ndim
-
-    start_indices[axis] = start_index
-    limit_indices[axis] = limit_index
-    strides[axis] = stride
-
-    return _slice_meta(a, start_indices, limit_indices, strides)
-
-
-def _slice_in_dim_aten(
-    a: Tensor,
-    start_index: int,
-    limit_index: int,
-    stride: int = 1,
-    axis: int = 0,
-) -> Tensor:
-    start_indices = [0] * a.ndim
-    limit_indices = list(a.shape)
-    strides = [1] * a.ndim
-
-    start_indices[axis] = start_index
-    limit_indices[axis] = limit_index
-    strides[axis] = stride
-
-    return slice(a, start_indices, limit_indices, strides)
-
-
-_slice_in_dim_doc = """
-    Convenience wrapper for slicing just one dimension using slice.
-    """
-
-# TODO: make stride SymInt
-slice_in_dim = _make_prim(
-    schema="slice_in_dim(Tensor(a) a, SymInt start_index, SymInt limit_index, int stride=1, int axis=0) -> Tensor(a)",
-    meta=_slice_in_dim_meta,
-    impl_aten=_slice_in_dim_aten,
-    return_type=RETURN_TYPE.VIEW,
-    doc=_slice_in_dim_doc,
-)
-
-
 def _split_dim_meta(a: TensorLikeType, dim: int, outer_length: int) -> TensorLikeType:
     assert isinstance(a, TensorLike)
     utils.validate_idx(a.ndim, dim)
@@ -1713,8 +1546,8 @@ def _split_dim_meta(a: TensorLikeType, dim: int, outer_length: int) -> TensorLik
         )
         raise ValueError(msg)
 
-    new_shape: List[int] = []
-    new_strides: List[int] = []
+    new_shape: list[int] = []
+    new_strides: list[int] = []
     for idx in range(a.ndim):
         if idx == dim:
             new_shape.extend((outer_length, inner_length))
@@ -1953,22 +1786,22 @@ def _cat_meta(tensors: Sequence[TensorLikeType], dim: int) -> TensorLikeType:
     # Verifies same shape (except in the concat dimension)
     assert dim >= 0
     shape = tensors[0].shape
-    concat_length = 0
+    sym_sum_args = []
     for tensor_idx, tensor in enumerate(tensors):
         assert len(shape) == len(tensor.shape)
         for idx, (common_length, length) in enumerate(zip(shape, tensor.shape)):
             if idx == dim:
-                concat_length = concat_length + length
+                sym_sum_args.append(length)
             else:
                 torch._check(
                     length == common_length,
                     lambda: f"Sizes of tensors must match except in dimension {dim}. "
-                    f"Expected {common_length} but got {length} for tensor number "
+                    f"Expected {common_length} in dimension {idx} but got {length} for tensor number "
                     f"{tensor_idx} in the list",
                 )
 
     new_shape = list(tensors[0].shape).copy()
-    new_shape[dim] = concat_length
+    new_shape[dim] = torch.sym_sum(sym_sum_args)
     return TensorMeta(
         tensors[0],
         shape=new_shape,
@@ -1976,7 +1809,7 @@ def _cat_meta(tensors: Sequence[TensorLikeType], dim: int) -> TensorLikeType:
     )
 
 
-def _cat_aten(tensors: Union[Tuple[Tensor, ...], List[Tensor]], dim: int) -> Tensor:
+def _cat_aten(tensors: Union[tuple[Tensor, ...], list[Tensor]], dim: int) -> Tensor:
     return torch.cat(tensors, dim)
 
 
@@ -2010,7 +1843,7 @@ def _reshape_meta(a: TensorLikeType, shape: ShapeType):
 
 
 def _reshape_aten(a: Tensor, shape: ShapeType) -> Tensor:
-    return a.reshape(shape).contiguous().clone()
+    return a.reshape(shape).clone(memory_format=torch.contiguous_format)
 
 
 _reshape_doc = """
@@ -2100,7 +1933,7 @@ def _convert_element_type_aten(a: Tensor, dtype: torch.dtype) -> Tensor:
         # TODO: update meta objects so this can be acquired directly
         try:
             requires_grad = a.requires_grad
-        except Exception as e:
+        except Exception:
             requires_grad = False
 
     result = torch.empty_like(
@@ -2125,16 +1958,19 @@ convert_element_type = _make_prim(
 
 
 def _device_put_meta(
-    a: TensorLikeType, device: Union[str, torch.device]
+    a: TensorLikeType, device: Union[str, torch.device], non_blocking=False
 ) -> TensorLikeType:
     assert isinstance(a, TensorLike)
     assert isinstance(device, (str, torch.device))
+    assert isinstance(non_blocking, bool)
 
     return TensorMeta(a, device=utils.canonicalize_device(device))
 
 
-def _device_put_aten(a: Tensor, device: Union[str, torch.device]) -> Tensor:
-    return a.to(device)
+def _device_put_aten(
+    a: Tensor, device: Union[str, torch.device], non_blocking=False
+) -> Tensor:
+    return a.to(device, non_blocking=non_blocking)
 
 
 _device_put_doc = """
@@ -2142,7 +1978,7 @@ _device_put_doc = """
   """
 
 device_put = _make_prim(
-    schema="device_put(Tensor a, Device device) -> Tensor",
+    schema="device_put(Tensor a, Device device, bool non_blocking=False) -> Tensor",
     meta=_device_put_meta,
     impl_aten=_device_put_aten,
     return_type=RETURN_TYPE.NEW,
@@ -2161,13 +1997,22 @@ _item_doc = """
     Converts a tensor with one element to a Python number.
 """
 
+
+# We can't call into python dispatcher for item again
+# because the current prim decomp calls into python dispatcher
+# again. https://github.com/pytorch/pytorch/issues/136050
+def _item_aten_no_python_dispatcher(*args, **kwargs):
+    with torch._dispatch.python.no_python_dispatcher():
+        return torch.Tensor.item(*args, **kwargs)
+
+
 # TODO: create a new return type for scalars?
 # FIXME: currently returns integers for boolean tensors
 # https://github.com/pytorch/pytorch/issues/78071
 item = _make_prim(
     schema="item(Tensor a) -> Scalar",
     meta=_item_meta,
-    impl_aten=torch.Tensor.item,
+    impl_aten=_item_aten_no_python_dispatcher,
     return_type=RETURN_TYPE.NEW,
     doc=_item_doc,
 )
@@ -2329,7 +2174,7 @@ def _resize_aten(a: Tensor, shape: ShapeType) -> Tensor:
 _resize_doc = """
   Gives a tensor with no elements a new shape, returning the modified tensor.
 
-  The tensor's strides are contiguous and its values are unitialized.
+  The tensor's strides are contiguous and its values are uninitialized.
   """
 
 # TODO: review support arbitrary resizes
@@ -2668,7 +2513,11 @@ def _full_aten(
 ) -> Tensor:
     # Note that Mypy thinks torch.full can't accept a complex fill_value
     return torch.full(
-        shape, fill_value, dtype=dtype, device=device, requires_grad=requires_grad  # type: ignore[arg-type]
+        shape,
+        fill_value,
+        dtype=dtype,
+        device=device,
+        requires_grad=requires_grad,  # type: ignore[arg-type]
     )
 
 
@@ -2711,7 +2560,11 @@ def _full_like_aten(
 ) -> Tensor:
     # Note that Mypy thinks torch.full can't accept a complex fill_value
     return torch.full_like(
-        a, fill_value, dtype=dtype, device=device, requires_grad=requires_grad  # type: ignore[arg-type]
+        a,
+        fill_value,
+        dtype=dtype,
+        device=device,
+        requires_grad=requires_grad,  # type: ignore[arg-type]
     )
 
 
@@ -2776,7 +2629,7 @@ scalar_tensor = _make_prim(
 
 def _svd_meta(
     A: TensorLikeType, *, full_matrices: bool
-) -> Tuple[TensorLikeType, TensorLikeType, TensorLikeType]:
+) -> tuple[TensorLikeType, TensorLikeType, TensorLikeType]:
     utils.check_is_matrix(A, "linalg.svd")
     utils.check_fp_or_complex(A.dtype, "linalg.svd", allow_low_precision_dtypes=False)
 
@@ -2813,7 +2666,7 @@ def _svd_meta(
 
 def _svd_aten(
     A: TensorLikeType, *, full_matrices: bool
-) -> Tuple[Tensor, Tensor, Tensor]:
+) -> tuple[Tensor, Tensor, Tensor]:
     return torch.linalg.svd(A, full_matrices=full_matrices)
 
 
@@ -3066,7 +2919,7 @@ fft_c2r = _make_prim(
 )
 
 
-def _frexp_meta(self: TensorLikeType) -> Tuple[TensorLikeType, TensorLikeType]:
+def _frexp_meta(self: TensorLikeType) -> tuple[TensorLikeType, TensorLikeType]:
     torch._check(
         self.dtype.is_floating_point,
         lambda: "torch.frexp() only supports floating-point dtypes",
